if [ -z $1 ]
  then
	echo USAGE: build.sh odroidu2_defconfig
	exit 0
fi

echo Backing up current kernel...
mkdir backup/
mkdir backup/boot/
mkdir backup/rootfs/
mkdir backup/rootfs/boot/
mkdir backup/rootfs/lib/
mkdir backup/rootfs/lib/modules/
cp /media/boot/* backup/boot/
cp /boot/* backup/rootfs/boot/
cp -r /lib/modules/`uname -r | cat` backup/rootfs/lib/modules/

mkdir release/
mkdir release/$1/
mkdir release/$1/boot/
mkdir release/$1/rootfs/
mkdir release/$1/rootfs/boot/

echo Cleaning build...
make mrproper
echo Creating config file...
make $1
echo Making zImage and modules...
make -j5 zImage modules

echo Copying files to release directory...
cp arch/arm/boot/zImage release/$1/boot
cp arch/arm/boot/zImage release/$1/rootfs/boot/vmlinuz-`cat include/config/kernel.release`

echo Making install...
make install

echo Making modules...
make modules_install

echo Compressing modules...
tar -cvzf release/$1/rootfs/modules.tgz /lib/modules/`cat include/config/kernel.release`

echo Copying config files...
cp .config release/$1/rootfs/boot/config-`cat include/config/kernel.release`
cp .config /boot/config-`cat include/config/kernel.release`

echo Building uInitrd phase 1 of 2..
update-initramfs -c -k `cat include/config/kernel.release`

echo Building uInitrd phase 2 of 2..
mkimage -A arm -O linux -T ramdisk -C none -a 0 -e 0 -n uInitrd -d /boot/initrd.img-`cat include/config/kernel.release` release/$1/rootfs/boot/uInitrd-`cat include/config/kernel.release`

echo Copying files and cleaning up..
cp release/$1/rootfs/boot/uInitrd-`cat include/config/kernel.release` release/$1/boot/uInitrd
mv /boot/*-`cat include/config/kernel.release` release/$1/rootfs/boot/
cp System.map release/$1/rootfs/boot/System.map-`cat include/config/kernel.release`
rm /media/boot/uImage

echo Copying installation script...
cp install.sh release/$1/ && chmod +x release/$1/install.sh

echo Restoring original /boot files...
cp backup/rootfs/boot/* /boot/
cp backup/boot/zImage /media/boot/zImage
cp backup/boot/uInitrd /media/boot/uInitrd

echo Restoring original modules...
rm -rf /lib/modules/`cat include/config/kernel.release`
cp -r backup/rootfs/lib/modules/* /lib/modules/
depmod -a

echo Release package contents:
ls -R release/$1/
echo The kernel compilation for $1 is done!  The installation files are  in the release/$1 folder.
